@@ -58,7 +58,8 @@ class SOFImageExtractor:
         return n.strip()
 
     def extract(self):
-        return list(map(self.processOcrLine, self.ocr(self.image).split("\n")))
+        #return list(map(self.processOcrLine, self.ocr(self.image).split("\n")))
+        return self.ocr(self.image)
 
 
 
@@ -163,7 +164,7 @@ class SOFTextExtractor:
             self.datepatterns = SOFTextExtractor.DATEPATTERNS
         pass
 
-    def extract(self, text, starttext=None, endtext=None, startdate=None, enddate=None, dateorder=None, timemask="hh:mm", timezone=timezone.utc):
+    def extract(self, text, starttext=None, endtext=None, startdate=None, enddate=None, dateorder=None, timemask="hh:mm", tz=timezone.utc):
         sofs = []
         summary_sofs = []
         date_count = startdate
@@ -174,10 +175,10 @@ class SOFTextExtractor:
             started = True
         for line in lines:
             if started and self.textContainsSof(line):
-                sof= self.extractLine(line, date_count, dateorder, timemask, timezone)
+                sof= self.extractLine(line, date_count, dateorder, timemask, tz)
                 if sof.startdatetime:
                     date_count = sof.startdatetime
-                sofs.append(sof)
+                sofs.append(sof) if sof not in sofs else sofs
                 if next((x for x in self.soflist.softypes if x.id == sof.id and x.summary), None):
                     summary_sofs.append(sof)
             elif started and self.extractDate(line,dateorder):
@@ -191,7 +192,7 @@ class SOFTextExtractor:
 
                 
 
-    def extractLine(self, text, date_count, dateorder, timemask, timezone=timezone.utc):
+    def extractLine(self, text, date_count, dateorder, timemask, tz=timezone.utc):
 
         restext = text
         softype = self.textContainsSof(text)
@@ -221,11 +222,11 @@ class SOFTextExtractor:
         if not time_from:
             time_from = date_from
         if date_from and time_from:
-            sof.startdatetime = self.generateDatetime(date_from, time_from,timezone)
+            sof.startdatetime = self.generateDatetime(date_from, time_from,tz)
         if softype.bounded and time_to:
             if not date_to:
                 date_to = date_from
-            sof.enddatetime = self.generateDatetime(date_to, time_to,timezone)
+            sof.enddatetime = self.generateDatetime(date_to, time_to,tz)
         return sof
 
     def textContainsSof(self, text):
@@ -308,8 +309,8 @@ class SOFTextExtractor:
     def checkDelim(self, delim):
         return delim != ""
 
-    def generateDatetime(self, dateobj, timeobj, timezone):
-        return datetime.datetime(year=dateobj.year, month=dateobj.month, day=dateobj.day,hour=timeobj.hour,minute=timeobj.minute, tzinfo=timezone.utc)
+    def generateDatetime(self, dateobj, timeobj, tz):
+        return datetime.datetime(year=dateobj.year, month=dateobj.month, day=dateobj.day,hour=timeobj.hour,minute=timeobj.minute, tzinfo=tz)
 
 
     def monthToNum(self, textMonth):
