@@ -43,10 +43,13 @@ class SOFExtractorTestCase(unittest.TestCase):
         extractor = SOFImageExtractor('./images/test_image.jpg','./tmpdata')
         result = extractor.extract()
         res = False
-        for line in result:
+        for line in result.splitlines():
             if "FINAL DRAFT SURVEY" in line:
                 res = True
         assert res
+        textextractor = SOFTextExtractor(self.generator)
+        sofs = textextractor.extract(result, dateorder="DMY", timemask="hhmm")
+        assert len(sofs) == 8
 
     def test_sof_generator(self):
         
@@ -97,7 +100,7 @@ class SOFExtractorTestCase(unittest.TestCase):
 
     def test_line_extractor(self):
         textextractor = SOFTextExtractor(self.generator)
-        sof = textextractor.extractLine(self.test_line_bounded1, None, "DMY", "hh.mm", timezone=timezone.utc)
+        sof = textextractor.extractLine(self.test_line_bounded1, None, "DMY", "hh.mm", tz=timezone.utc)
         assert sof.id
         assert sof.description == "HOLD CLEANING"
         assert sof.type == SHC + "HOLD-CLEANING"
@@ -120,6 +123,9 @@ class SOFExtractorTestCase(unittest.TestCase):
         assert sofs3[0].startdatetime.month == 8
         assert sofs3[0].startdatetime.day == 12
 
+        sofs4 = textextractor.extract(self.softext, dateorder="DMY", timemask="hh:mm")
+        assert len(sofs) == 10
+
 
     def test_pdfextractor(self):
         extractor = SOFPDFExtractor('./pdfs/test.pdf')
